@@ -33,12 +33,15 @@
 #include <QDebug>
 #include <XdgIcon>
 #include <KWindowSystem/KWindowSystem>
+#include <QMouseEvent>
+#include <QPushButton>
 
 #include "notification.h"
 #include "notificationwidgets.h"
 
 #define ICONSIZE QSize(32, 32)
 
+
 Notification::Notification(const QString &application,
                            const QString &summary, const QString &body,
                            const QString &icon, int timeout,
@@ -46,6 +49,7 @@ Notification::Notification(const QString &application,
                            QWidget *parent)
     : QWidget(parent),
       m_timer(0),
+      m_linkHovered(false),
       m_actionWidget(0)
 {
     setupUi(this);
@@ -57,7 +61,14 @@ Notification::Notification(const QString &application,
 
     setValues(application, summary, body, icon, timeout, actions, hints);
 
-    connect(closeButton, SIGNAL(clicked()), this, SLOT(closeButton_clicked()));
+    connect(closeButton, &QPushButton::clicked, this, &Notification::closeButton_clicked);
+
+    for (QLabel *label : {bodyLabel, summaryLabel})
+    {
+        connect(label, &QLabel::linkHovered, this, &Notification::linkHovered);
+
+        label->installEventFilter(this);
+    }
 }
 
 void Notification::setValues(const QString &application,
@@ -77,22 +88,18 @@ void Notification::setValues(const QString &application,
     if (!hints["image_data"].isNull())
     {
         m_pixmap = getPixmapFromHint(hints["image_data"]);
-//        qDebug() << application << "from image_data" << m_pixmap.isNull();
     }
     else if (!hints["image_path"].isNull())
     {
         m_pixmap = getPixmapFromString(hints["image_path"].toString());
-//        qDebug() << application << "from image_path" << m_pixmap.isNull();
     }
     else if (!icon.isEmpty())
     {
         m_pixmap = getPixmapFromString(icon);
-//        qDebug() << application << "from icon" << icon << m_pixmap.isNull();
     }
     else if (!hints["icon_data"].isNull())
     {
        m_pixmap = getPixmapFromHint(hints["icon_data"]);
-//       qDebug() << application << "from icon_data" << m_pixmap.isNull();
     }
     // issue #325: Do not display icon if it's not found...
     if (m_pixmap.isNull())
@@ -145,15 +152,14 @@ void Notification::setValues(const QString &application,
     if (timeout > 0)
     {
         m_timer = new NotificationTimer(this);
-        connect(m_timer, SIGNAL(timeout()), this, SIGNAL(timeout()));
+        connect(m_timer, &NotificationTimer::timeout, this, &Notification::timeout);
         m_timer->start(timeout);
     }
 
     // Categories *********************
-    // TODO/FIXME: Categories - how to handle it?
     if (!hints["category"].isNull())
     {
-        qDebug() << "Notification" << application << "category" << hints["category"];
+        // TODO/FIXME: Categories - how to handle it?
     }
 
     // Urgency Levels *********************
@@ -161,10 +167,9 @@ void Notification::setValues(const QString &application,
     // 0   Low
     // 1   Normal
     // 2   Critical
-    // TODO/FIXME: Urgencies - how to handle it?
     if (!hints["urgency"].isNull())
     {
-        qDebug() << "Notification" << application << "urgency" << hints["urgency"];
+        // TODO/FIXME: Urgencies - how to handle it?
     }
 
     // Actions
@@ -174,8 +179,10 @@ void Notification::setValues(const QString &application,
             m_actionWidget = new NotificationActionsButtonsWidget(actions, this);
         else
             m_actionWidget = new NotificationActionsComboWidget(actions, this);
-        connect(m_actionWidget, SIGNAL(actionTriggered(const QString &)),
-                this, SIGNAL(actionTriggered(const QString &)));
+
+        connect(m_actionWidget, &NotificationActionsWidget::actionTriggered,
+                this, &Notification::actionTriggered);
+
         actionsLayout->addWidget(m_actionWidget);
         m_actionWidget->show();
     }
@@ -272,6 +279,25 @@ void Notification::leaveEvent(QEvent * event)
         m_timer->resume();
 }
 
+bool Notification::eventFilter(QObject *obj, QEvent *event)
+{
+    // Catch mouseReleaseEvent on child labels if a link is not currently being hovered.
+    //
+    // This workarounds QTBUG-49025 where clicking on text does not propagate the mouseReleaseEvent
+    // to the parent even though the text is not selectable and no link is being clicked.
+    if (event->type() == QEvent::MouseButtonRelease && !m_linkHovered)
+    {
+        mouseReleaseEvent(static_cast<QMouseEvent*>(event));
+        return true;
+    }
+    return false;
+}
+
+void Notification::linkHovered(QString link)
+{
+    m_linkHovered = !link.isEmpty();
+}
+
 void Notification::mouseReleaseEvent(QMouseEvent * event)
 {
 //    qDebug() << "CLICKED" << event;
